@@ -2,7 +2,7 @@
 //============================================================+
 // File name   : example_015.php
 // Begin       : 2008-03-04
-// Last Update : 2010-05-20
+// Last Update : 2011-04-15
 //
 // Description : Example 015 for TCPDF class
 //               Bookmarks (Table of Content)
@@ -24,9 +24,6 @@
  * @package com.tecnick.tcpdf
  * @abstract TCPDF - Example: Bookmarks (Table of Content)
  * @author Nicola Asuni
- * @copyright 2004-2009 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
- * @link http://tcpdf.org
- * @license http://www.gnu.org/copyleft/lesser.html LGPL
  * @since 2008-03-04
  */
 
@@ -69,7 +66,7 @@ $pdf->setLanguageArray($l);
 
 // ---------------------------------------------------------
 
-// Bookmark($txt, $level=0, $y=-1, $page='')
+// Bookmark($txt, $level=0, $y=-1, $page='', $style='', $color=array(0,0,0))
 
 // set font
 $pdf->SetFont('times', 'B', 20);
@@ -78,7 +75,7 @@ $pdf->SetFont('times', 'B', 20);
 $pdf->AddPage();
 
 // set a bookmark for the current position
-$pdf->Bookmark('Chapter 1', 0, 0);
+$pdf->Bookmark('Chapter 1', 0, 0, '', 'B', array(0,64,128));
 
 // print a line using Cell()
 $pdf->Cell(0, 10, 'Chapter 1', 0, 1, 'L');
@@ -91,27 +88,27 @@ $pdf->SetFont('times', 'B', 20);
 // add other pages and bookmarks
 
 $pdf->AddPage();
-$pdf->Bookmark('Paragraph 1.1', 1, 0);
+$pdf->Bookmark('Paragraph 1.1', 1, 0, '', '', array(0,0,0));
 $pdf->Cell(0, 10, 'Paragraph 1.1', 0, 1, 'L');
 
 $pdf->AddPage();
-$pdf->Bookmark('Paragraph 1.2', 1, 0);
+$pdf->Bookmark('Paragraph 1.2', 1, 0, '', '', array(0,0,0));
 $pdf->Cell(0, 10, 'Paragraph 1.2', 0, 1, 'L');
 
 $pdf->AddPage();
-$pdf->Bookmark('Sub-Paragraph 1.2.1', 2, 0);
+$pdf->Bookmark('Sub-Paragraph 1.2.1', 2, 0, '', 'I', array(0,0,0));
 $pdf->Cell(0, 10, 'Sub-Paragraph 1.2.1', 0, 1, 'L');
 
 $pdf->AddPage();
-$pdf->Bookmark('Paragraph 1.3', 1, 0);
+$pdf->Bookmark('Paragraph 1.3', 1, 0, '', '', array(0,0,0));
 $pdf->Cell(0, 10, 'Paragraph 1.3', 0, 1, 'L');
 
 $pdf->AddPage();
-$pdf->Bookmark('Chapter 2', 0, 0);
+$pdf->Bookmark('Chapter 2', 0, 0, '', 'BI', array(128,0,0));
 $pdf->Cell(0, 10, 'Chapter 2', 0, 1, 'L');
 
 $pdf->AddPage();
-$pdf->Bookmark('Chapter 3', 0, 0);
+$pdf->Bookmark('Chapter 3', 0, 0, '', 'B', array(0,64,128));
 $pdf->Cell(0, 10, 'Chapter 3', 0, 1, 'L');
 
 // ---------------------------------------------------------
@@ -120,6 +117,5 @@ $pdf->Cell(0, 10, 'Chapter 3', 0, 1, 'L');
 $pdf->Output('example_015.pdf', 'I');
 
 //============================================================+
-// END OF FILE                                                
+// END OF FILE
 //============================================================+
-?>
