@@ -2,7 +2,7 @@
 //============================================================+
 // File name   : example_033.php
 // Begin       : 2008-06-24
-// Last Update : 2010-05-20
+// Last Update : 2010-08-08
 //
 // Description : Example 033 for TCPDF class
 //               Mixed font types
@@ -24,9 +24,6 @@
  * @package com.tecnick.tcpdf
  * @abstract TCPDF - Example: Mixed font types
  * @author Nicola Asuni
- * @copyright 2004-2009 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
- * @link http://tcpdf.org
- * @license http://www.gnu.org/copyleft/lesser.html LGPL
  * @since 2008-06-24
  */
 
@@ -72,6 +69,9 @@ $pdf->setLanguageArray($l);
 // add a page
 $pdf->AddPage();
 
+// set default font subsetting mode
+$pdf->setFontSubsetting(false);
+
 $pdf->SetFont('helvetica', 'B', 20);
 
 $pdf->Write(0, 'Font Types', '', 0, 'C', 1, 0, false, false, 0);
@@ -103,4 +103,3 @@ $pdf->Output('example_033.pdf', 'I');
 //============================================================+
 // END OF FILE                                                
 //============================================================+
-?>
