@@ -2,7 +2,7 @@
 //============================================================+
 // File name   : example_055.php
 // Begin       : 2009-10-21
-// Last Update : 2010-05-20
+// Last Update : 2010-12-27
 //
 // Description : Example 055 for TCPDF class
 //               Display all characters available on core fonts.
@@ -24,9 +24,6 @@
  * @package com.tecnick.tcpdf
  * @abstract TCPDF - Example: XHTML Forms
  * @author Nicola Asuni
- * @copyright 2004-2009 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
- * @link http://tcpdf.org
- * @license http://www.gnu.org/copyleft/lesser.html LGPL
  * @since 2009-10-21
  */
 
@@ -70,38 +67,44 @@ $pdf->setLanguageArray($l);
 // ---------------------------------------------------------
 
 // set font
-$pdf->SetFont('helvetica', '', 10);
+$pdf->SetFont('helvetica', '', 14);
 
-// add a page
-$pdf->AddPage();
-
-// array of core font names
+// array of font names
 $core_fonts = array('courier', 'helvetica', 'times', 'symbol', 'zapfdingbats');
 
-$html = '<h1>Core Fonts Dump</h1>';
+// set fill color
+$pdf->SetFillColor(221,238,255);
 
 // create one HTML table for each core font
 foreach($core_fonts as $font) {
-	// create HTML content
-	$html .= '<table cellpadding="1" cellspacing="0" border="1" nobr="true" style="font-family:'.$font.';text-align:center;">';
-	$html .= '<tr style="background-color:yellow;"><td colspan="16" style="font-family:helvetica;font-weight:bold">'.strtoupper($font).'</td></tr><tr>';
+	// add a page
+	$pdf->AddPage();
+	
+	// Cell($w, $h=0, $txt='', $border=0, $ln=0, $align='', $fill=false, $link='', $stretch=0, $ignore_min_height=false, $calign='T', $valign='M')
+	
+	// set font for title
+	$pdf->SetFont('helvetica', 'B', 16);
+	
+	// print font name
+	$pdf->Cell(0, 10, 'FONT: '.$font, 1, 1, 'C', true, '', 0, false, 'T', 'M');
+	
+	// set font for chars
+	$pdf->SetFont($font, '', 16);
+	
 	// print each character
 	for ($i = 0; $i < 256; ++$i) {
 		if (($i > 0) AND (($i % 16) == 0)) {
-			$html .= '</tr><tr>';
+			$pdf->Ln();
 		}
-		$chr = $pdf->unichr($i);
-		// replace special characters
-		$trans = array('<' => '&lt;', '>' => '&gt;');
-		$chr = strtr($chr, $trans);
-		$html .= '<td>'.$chr.'</td>';
+		$pdf->Cell(11.25, 11.25, $pdf->unichr($i), 1, 0, 'C', false, '', 0, false, 'T', 'M');
 	}
-	$html .= '</tr></table><br />&nbsp;<br />';
+	
+	$pdf->Ln(20);
+	
+	// print a pangram
+	$pdf->Cell(0, 0, 'The quick brown fox jumps over the lazy dog', 0, 1, 'C', false, '', 0, false, 'T', 'M');
 }
 
-// output the HTML content
-$pdf->writeHTML($html, true, false, true, false, '');
-
 // ---------------------------------------------------------
 
 //Close and output PDF document
@@ -110,4 +113,3 @@ $pdf->Output('example_055.pdf', 'I');
 //============================================================+
 // END OF FILE                                                
 //============================================================+
-?>
